{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Run pindel on provided region",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "default": 400,
                    "id": "#main/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/normal_bam"
                },
                {
                    "type": "string",
                    "id": "#main/normal_sample_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "pindel.vcf",
                    "id": "#main/output_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "GRCh38DH",
                    "id": "#main/ref_name"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/region_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/tumor_bam"
                },
                {
                    "type": "string",
                    "id": "#main/tumor_sample_name"
                }
            ],
            "steps": [
                {
                    "run": "#cat_out.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/pindel_region/deletions",
                                "#main/pindel_region/insertions",
                                "#main/pindel_region/tandems",
                                "#main/pindel_region/long_insertions",
                                "#main/pindel_region/inversions"
                            ],
                            "id": "#main/cat/pindel_outs"
                        }
                    ],
                    "out": [
                        "#main/cat/pindel_out"
                    ],
                    "id": "#main/cat"
                },
                {
                    "run": "#fix_vcf_header.cwl",
                    "in": [
                        {
                            "source": "#main/pindel2vcf/pindel_vcf",
                            "id": "#main/fix_vcf_header/vcf"
                        }
                    ],
                    "out": [
                        "#main/fix_vcf_header/fixed_vcf"
                    ],
                    "id": "#main/fix_vcf_header"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/remove_end_tags/processed_vcf",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                },
                {
                    "run": "#pindel2vcf.cwl",
                    "in": [
                        {
                            "source": "#main/output_name",
                            "id": "#main/pindel2vcf/output_name"
                        },
                        {
                            "source": "#main/cat/pindel_out",
                            "id": "#main/pindel2vcf/pindel_out"
                        },
                        {
                            "source": "#main/ref_name",
                            "id": "#main/pindel2vcf/ref_name"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/pindel2vcf/reference"
                        }
                    ],
                    "out": [
                        "#main/pindel2vcf/pindel_vcf"
                    ],
                    "id": "#main/pindel2vcf"
                },
                {
                    "run": "#pindel.cwl",
                    "in": [
                        {
                            "source": "#main/insert_size",
                            "id": "#main/pindel_region/insert_size"
                        },
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/pindel_region/normal_bam"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/pindel_region/normal_sample_name"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/pindel_region/reference"
                        },
                        {
                            "source": "#main/region_file",
                            "id": "#main/pindel_region/region_file"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/pindel_region/tumor_bam"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/pindel_region/tumor_sample_name"
                        }
                    ],
                    "out": [
                        "#main/pindel_region/deletions",
                        "#main/pindel_region/insertions",
                        "#main/pindel_region/tandems",
                        "#main/pindel_region/long_insertions",
                        "#main/pindel_region/inversions"
                    ],
                    "id": "#main/pindel_region"
                },
                {
                    "run": "#remove_end_tags.cwl",
                    "in": [
                        {
                            "source": "#main/fix_vcf_header/fixed_vcf",
                            "id": "#main/remove_end_tags/vcf"
                        }
                    ],
                    "out": [
                        "#main/remove_end_tags/processed_vcf"
                    ],
                    "id": "#main/remove_end_tags"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/pindel_region_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/cat"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:xenial"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "per_chromosome_pindel.out",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat_out.cwl/pindel_outs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat_out.cwl/pindel_out",
                    "outputBinding": {
                        "glob": "per_chromosome_pindel.out"
                    }
                }
            ],
            "id": "#cat_out.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "fix vcf header",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "FixVcfHeader"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.vcf.basename).gz"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "id": "#fix_vcf_header.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename).gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fix_vcf_header.cwl/fixed_vcf"
                }
            ],
            "id": "#fix_vcf_header.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "pindel v0.2.5b8",
            "arguments": [
                "/usr/bin/perl",
                "pindel_helper.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 100000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.4.2"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "pindel_helper.pl",
                            "entry": "#!/usr/bin/perl\n\nuse strict;\nuse warnings;\n\nuse IO::File;\n\nunless (@ARGV > 5) {\n    die \"Usage: $0 normal.bam tumor.bam insert_size normal_sample_name tumor_sample_name <args>\";\n}\n\nmy ($normal_bam, $tumor_bam, $insert_size, $normal_name, $tumor_name, @args) = @ARGV;\n\nmy $fh = IO::File->new(\"> pindel.config\");\n\n$fh->say(join(\"\\t\", $normal_bam, $insert_size, $normal_name));\n$fh->say(join(\"\\t\", $tumor_bam, $insert_size, $tumor_name));\n$fh->close;\n\nexit system(qw(/usr/bin/pindel -i pindel.config -w 30 -T 4 -o all), @args);\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-c",
                        "position": 7
                    },
                    "id": "#pindel.cwl/chromosome"
                },
                {
                    "type": "int",
                    "default": 400,
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#pindel.cwl/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#pindel.cwl/normal_bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#pindel.cwl/normal_sample_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 6
                    },
                    "id": "#pindel.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-j",
                        "position": 8
                    },
                    "id": "#pindel.cwl/region_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#pindel.cwl/tumor_bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#pindel.cwl/tumor_sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_D"
                    },
                    "id": "#pindel.cwl/deletions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_SI"
                    },
                    "id": "#pindel.cwl/insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_INV"
                    },
                    "id": "#pindel.cwl/inversions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_LI"
                    },
                    "id": "#pindel.cwl/long_insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_TD"
                    },
                    "id": "#pindel.cwl/tandems"
                }
            ],
            "id": "#pindel.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "pindel v0.2.5b8",
            "baseCommand": [
                "/usr/bin/pindel2vcf"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "tmpdirMin": 100000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                }
            ],
            "arguments": [
                "-G",
                "-d",
                "20161216"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-e"
                    },
                    "default": 3,
                    "id": "#pindel2vcf.cwl/min_supporting_reads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-v"
                    },
                    "default": "pindel.vcf",
                    "id": "#pindel2vcf.cwl/output_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#pindel2vcf.cwl/pindel_out"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "default": "GRCh38DH",
                    "id": "#pindel2vcf.cwl/ref_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#pindel2vcf.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#pindel2vcf.cwl/pindel_vcf"
                }
            ],
            "id": "#pindel2vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "remove END INFO tags",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "annotate"
            ],
            "arguments": [
                "-x",
                "INFO/END",
                "-Oz",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/pindel.noend.vcf.gz"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.3.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#remove_end_tags.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pindel.noend.vcf.gz"
                    },
                    "id": "#remove_end_tags.cwl/processed_vcf"
                }
            ],
            "id": "#remove_end_tags.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
